@@ -8,11 +8,20 @@
 Copyright (c) 2011, Nat Goodspeed
 """
 
+from builtins import object
 import os
 import errno
 import shutil
+import sys
 import tempfile
 
+if sys.version_info[0] >= 3:
+    # NamedTemporaryFile(buffering=)
+    _bufparam = 'buffering'
+else:
+    # NamedTemporaryFile(bufsize=)
+    _bufparam = 'bufsize'
+
 class ReplaceFile(object):
     """
     ReplaceFile is a ContextManager to assist in filtering and replacing a
@@ -102,9 +111,10 @@ class ReplaceFile(object):
             # default buffer size?) We don't care what the name is -- but we
             # DO insist that it be placed in the same directory as
             # self.filename: if that dir isn't writable, we need to know now.
-            self.outf = tempfile.NamedTemporaryFile(mode=self.outmode, bufsize=16*1024,
+            self.outf = tempfile.NamedTemporaryFile(mode=self.outmode,
                                                     dir=os.path.dirname(self.filename),
-                                                    delete=False)
+                                                    delete=False,
+                                                    **{ _bufparam: 16*1024 })
             self.outname = self.outf.name
         return self.inf, self.outf
 
@@ -135,7 +145,7 @@ class ReplaceFile(object):
             # oldname.
             try:
                 os.remove(oldname)
-            except OSError, err:
+            except OSError as err:
                 if err.errno != errno.ENOENT:
                     # If the remove() error isn't nonexistence, holler about it.
                     raise
